/*==============================================================================


       eg_15 - Multi-Lingual Programming

               Copyright  2001 Pankhurst Algorithmics - All Rights Reserved
               visit www.ebmDevMag.com for permissions/restrictions on use

==============================================================================*/
#include <string.h>
#include <locale.h>

#include "gui.h"
#include "ebm_object.h"

extern "C"
{
#include "ereader_hostio.h"
}
#include "eg_15_form.h"
#include "lang_fun.h"
/*==============================================================================

       main window

==============================================================================*/
void CWindow1::Initialize(void)
{
  // get os language, and set up appropriate language array
  LANG_Set_Language_String( LANG_Get_OS_Version() );
  // set text strings for display objects
  TEXT->SetLabel( LANG_Str(e_TEXT) );
  CAPTION->SetLabel( LANG_Str(e_BUTTON) );
  BUTTON->SetLabel( LANG_Str(e_CANCEL) );
}
//------------------------------------------------------------------------------
void CWindow1::HandleRadioButtons(CViewable *from, S32 data)
{
  // allow only one down, and handle action of down press
  CRadioButton *button=(CRadioButton*)from;
  // create a list of buttons and languages, to make checking a simple for loop
  CRadioButton *ptr[]={ RadioButton_ENGLISH,
                        RadioButton_FRENCH,
                        RadioButton_DUTCH,
                        RadioButton_GERMAN,
                        RadioButton_SPANISH };
  const int total=sizeof(ptr)/sizeof(ptr[0]);
  // array to define which radio button is which language
  LANG_MODE buttonLanguage[] = { LANG_ENGLISH, LANG_FRENCH, LANG_DUTCH, LANG_GERMAN, LANG_SPANISH };
  int i=0, index=0;
  for (i=0;i<total;i++)
  {
    if ( ptr[i]->GetDownStatus() ) // turn off all buttons
      ptr[i]->SetDownStatus(false);
    // as well, check which language is selected, and set it
    if ( button==ptr[i] ) // our button? then save index
      index=i;
  }
  // now set our button on, and redraw all text in new language
  button->SetDownStatus(true);
  LANG_Set_Language_String( buttonLanguage[index] );
  TEXT->SetLabel( LANG_Str(e_TEXT) );
  CAPTION->SetLabel( LANG_Str(e_BUTTON) );
  BUTTON->SetLabel( LANG_Str(e_CANCEL) );
}
//------------------------------------------------------------------------------
S32 CWindow1::MsgHandler( MSG_TYPE type, CViewable *from, S32 data )
{
  // process button/radio button messages
  if ( MSG_BUTTON_SELECT==type )
  {
    switch (from->GetID())
    {
      case CWindow1_RadioButton_ENGLISH:
      case CWindow1_RadioButton_FRENCH:
      case CWindow1_RadioButton_DUTCH:
      case CWindow1_RadioButton_GERMAN:
      case CWindow1_RadioButton_SPANISH:
        HandleRadioButtons(from,data);
        break;
      case CWindow1_BUTTON:
        GUI_Alert( ALERT_WARNING, LANG_Str(e_HELLO) ); // say hi now...
        break;
    }
  }
  return CWindow::MsgHandler(type, from, data);
}
/*==============================================================================


==============================================================================*/
static CWindow1 *f_mainWindow;
//------------------------------------------------------------------------------
S32 GUI_main( MSG_TYPE type, CViewable *object, S32 data )
{
  switch (type)
  {
    case MSG_APP_START:
      if (OS_is_present && hostIO_am_I_the_current_task())
        HOSTIO_INLINE_BREAKPOINT();
      f_mainWindow = new CWindow1();
      f_mainWindow->Initialize();
      return 1;
    case MSG_APP_STOP:
      delete f_mainWindow;
      return 1;
    default:
      break;
  }
  return 0;
};
//------------------------------------------------------------------------------



