/*==============================================================================


       lang_fun.cpp - Multi-Lingual Programming

               Copyright  2001 Pankhurst Algorithmics - All Rights Reserved
               visit www.ebmDevMag.com for permissions/restrictions on use

==============================================================================*/
#include <string.h>
#include <locale.h>

#include "gui_pkg.h"
/*==============================================================================

       setting up our multiple language strings - simple way (non-resource):

       #1 - create an array of enums in the header, one for each string

==============================================================================*/
#include "lang_fun.h"
/*==============================================================================

       #2 - place the translations we have available listed in an array

==============================================================================*/
LANG_MODE s_arrayOrder[] = { LANG_ENGLISH,
                             LANG_DUTCH,
                             LANG_SPANISH,
                             LANG_FRENCH,
                             LANG_GERMAN };
const int s_maxLanguage=sizeof(s_arrayOrder)/sizeof(s_arrayOrder[0]);
/*==============================================================================

       #3 - list the translations, organized in the order specified in s_arrayOrder

==============================================================================*/
extern const char *s_languageStrings[s_maxLanguage][4]={
   { "button",    "text",          "cancel",      "hello"   },
   { "drukknoop", "tekst",         "afbestellen", "hallo"   },
   { "botn",     "texto",         "cancelacin ","hola"    },
   { "bouton",    "texte",         "annuler",     "bonjour" },
   { "der taster","der zeilentext","zurckziehen","hallo"   } };
/*==============================================================================

       #4 - functions to change/access the current language

==============================================================================*/
int s_currLangIndex=0; // index to above strings - default is first entries (english)
//------------------------------------------------------------------------------
void LANG_Set_Language_String(LANG_MODE language)
{
  for (int i=0;i<s_maxLanguage;i++)
  {
    if ( language == s_arrayOrder[i] )
    {
      s_currLangIndex=i;
      break;
    }
  }
  // if we fail, then the index remains as it was
}
//------------------------------------------------------------------------------
const char *LANG_Str(enum LANG_STRING_INDEX index)
{
  return s_languageStrings[s_currLangIndex][(int)index];
}
/*==============================================================================

       Get OS Language

==============================================================================*/
LANG_MODE s_language = LANG_MAX; // sentinel to tell us we haven't checked yet
//------------------------------------------------------------------------------
LANG_MODE LANG_Get_OS_Version(void)
{
  // look for appropriate language - if unknown, return LANG_NONE
  // really only needs to be called once to set s_language variable
  // for convenience we also reuse the LANG_MODE rnums form pen.h
  // rather than create our own
  if ( LANG_MAX == s_language ) // first time in? then look up value
  {
    const char *oslang = PKG_String( GUI_pkg, GUI_PACKAGE_NAME );
    if ( 0==stricmp("GUI_American",oslang) )
      s_language=LANG_ENGLISH;
    else if ( 0==stricmp("GUI_Nederlands",oslang) )
      s_language=LANG_DUTCH;
    else if ( 0==stricmp("GUI_Espaol",oslang) )
      s_language=LANG_SPANISH;
    else if ( 0==stricmp("GUI_Franais",oslang) )
      s_language=LANG_FRENCH;
    else if ( 0==stricmp("GUI_Deutsch",oslang) )
      s_language=LANG_GERMAN;
    else // unknown!
      s_language=LANG_NONE;
  }
  return s_language;
}
//------------------------------------------------------------------------------



